//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/SampleDesigner/SampleViewFactory.cpp
//! @brief     Implements class SampleViewFactory
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/SampleDesigner/SampleViewFactory.h"
#include "GUI/Model/Sample/InterferenceItems.h"
#include "GUI/Model/Sample/LayerItem.h"
#include "GUI/Model/Sample/MesoCrystalItem.h"
#include "GUI/Model/Sample/MultiLayerItem.h"
#include "GUI/Model/Sample/ParticleCompositionItem.h"
#include "GUI/Model/Sample/ParticleCoreShellItem.h"
#include "GUI/Model/Sample/ParticleItem.h"
#include "GUI/Model/Sample/ParticleLayoutItem.h"
#include "GUI/Model/Trafo/TransformationItem.h"
#include "GUI/View/SampleDesigner/InterferenceViews.h"
#include "GUI/View/SampleDesigner/LayerView.h"
#include "GUI/View/SampleDesigner/MesoCrystalView.h"
#include "GUI/View/SampleDesigner/MultiLayerView.h"
#include "GUI/View/SampleDesigner/ParticleCompositionView.h"
#include "GUI/View/SampleDesigner/ParticleCoreShellView.h"
#include "GUI/View/SampleDesigner/ParticleLayoutView.h"
#include "GUI/View/SampleDesigner/ParticleView.h"
#include "GUI/View/SampleDesigner/TransformationView.h"

bool SampleViewFactory::isValidType(const QString& model_type)
{
    return model_type.startsWith("FormFactor") || model_type == MultiLayerItem::M_TYPE
           || model_type == LayerItem::M_TYPE || model_type == ParticleLayoutItem::M_TYPE
           || model_type == ParticleItem::M_TYPE || model_type == TransformationItem::M_TYPE
           || model_type == ParticleCoreShellItem::M_TYPE
           || model_type == ParticleCompositionItem::M_TYPE || model_type == MesoCrystalItem::M_TYPE
           || model_type == Interference1DLatticeItem::M_TYPE
           || model_type == Interference2DLatticeItem::M_TYPE
           || model_type == Interference2DParaCrystalItem::M_TYPE
           || model_type == InterferenceFinite2DLatticeItem::M_TYPE
           || model_type == InterferenceHardDiskItem::M_TYPE
           || model_type == InterferenceRadialParaCrystalItem::M_TYPE;
}

IView* SampleViewFactory::createSampleView(const QString& model_type)
{
    if (model_type == MultiLayerItem::M_TYPE)
        return new MultiLayerView();
    if (model_type == LayerItem::M_TYPE)
        return new LayerView();
    if (model_type == ParticleLayoutItem::M_TYPE)
        return new ParticleLayoutView();
    if (model_type == ParticleItem::M_TYPE)
        return new ParticleView();
    if (model_type == TransformationItem::M_TYPE)
        return new TransformationView();
    if (model_type == ParticleCoreShellItem::M_TYPE)
        return new ParticleCoreShellView();
    if (model_type == ParticleCompositionItem::M_TYPE)
        return new ParticleCompositionView();
    if (model_type == MesoCrystalItem::M_TYPE)
        return new MesoCrystalView();
    if (model_type == Interference1DLatticeItem::M_TYPE)
        return new Interference1DLatticeView();
    if (model_type == Interference2DLatticeItem::M_TYPE)
        return new Interference2DLatticeView();
    if (model_type == Interference2DParaCrystalItem::M_TYPE)
        return new Interference2DParaCrystalView();
    if (model_type == InterferenceFinite2DLatticeItem::M_TYPE)
        return new InterferenceFinite2DLatticeView();
    if (model_type == InterferenceHardDiskItem::M_TYPE)
        return new InterferenceHardDiskView();
    if (model_type == InterferenceRadialParaCrystalItem::M_TYPE)
        return new InterferenceRadialParaCrystalView();
    return nullptr;
}
